@@ -79,7 +79,7 @@ class HoloviewsWriter(AbstractVersionedDataSet):
         """Creates a new instance of ``HoloviewsWriter``.
 
         Args:
-            filepath: Filepath to a text file prefixed with a protocol like `s3://`.
+            filepath: Filepath in POSIX format to a text file prefixed with a protocol like `s3://`.
                 If prefix is not provided, `file` protocol (local filesystem) will be used.
                 The prefix should be any protocol supported by ``fsspec``.
                 Note: `http(s)` doesn't support versioning.
