@@ -106,13 +106,15 @@ def lint(files, check_only):
     """Run flake8, isort and black."""
     static_data = get_static_project_data(Path.cwd())
     source_path = static_data["source_dir"]
-    package_name = static_data["package_name"]
+    package_name = (
+        static_data.get("package_name") or _load_project_context().package_name
+    )
     files = files or (str(source_path / "tests"), str(source_path / package_name))
 
     if "PYTHONPATH" not in os.environ:
         # isort needs the source path to be in the 'PYTHONPATH' environment
         # variable to treat it as a first-party import location
-        os.environ["PYTHONPATH"] = str(source_path)
+        os.environ["PYTHONPATH"] = str(source_path)  # pragma: no cover
 
     for module_name in ("flake8", "isort", "black"):
         try:
@@ -151,7 +153,7 @@ def install(compile_flag):
     requirements_txt = source_path / "requirements.txt"
 
     if environment_yml.is_file():
-        call(["conda", "install", "--file", str(environment_yml), "--yes"])
+        call(["conda", "env", "update", "--file", str(environment_yml), "--prune"])
 
     default_compile = bool(compile_flag is None and not requirements_in.is_file())
     do_compile = compile_flag or default_compile
@@ -211,7 +213,9 @@ def build_docs(open_docs):
     """Build the project documentation."""
     static_data = get_static_project_data(Path.cwd())
     source_path = static_data["source_dir"]
-    package_name = static_data["package_name"]
+    package_name = (
+        static_data.get("package_name") or _load_project_context().package_name
+    )
 
     python_call("pip", ["install", str(source_path / "[docs]")])
     python_call("pip", ["install", "-r", str(source_path / "requirements.txt")])
