@@ -50,6 +50,11 @@ from kedro.utils import load_obj
 DATASET_CREDENTIALS_KEY = "dataset_credentials"
 CHECKPOINT_CREDENTIALS_KEY = "checkpoint_credentials"
 
+KEY_PROPAGATION_WARNING = (
+    "Top-level %(keys)s will not propagate into the %(target)s since "
+    "%(keys)s were explicitly defined in the %(target)s config."
+)
+
 S3_PROTOCOLS = ("s3", "s3a", "s3n")
 
 
@@ -99,6 +104,7 @@ class PartitionedDataSet(AbstractDataSet):
         filename_suffix: str = "",
         credentials: Dict[str, Any] = None,
         load_args: Dict[str, Any] = None,
+        fs_args: Dict[str, Any] = None,
     ):
         """Creates a new instance of ``PartitionedDataSet``.
 
@@ -136,6 +142,8 @@ class PartitionedDataSet(AbstractDataSet):
                 https://kedro.readthedocs.io/en/stable/04_user_guide/08_advanced_io.html#partitioned-dataset-credentials
             load_args: Keyword arguments to be passed into ``find()`` method of
                 the filesystem implementation.
+            fs_args: Extra arguments to pass into underlying filesystem class constructor
+                (e.g. `{"project": "my-project"}` for ``GCSFileSystem``)
 
         Raises:
             DataSetError: If versioning is enabled for the underlying dataset.
@@ -164,13 +172,22 @@ class PartitionedDataSet(AbstractDataSet):
         if dataset_credentials:
             if CREDENTIALS_KEY in self._dataset_config:
                 self._logger.warning(
-                    "Top-level credentials will not propagate into the "
-                    "underlying dataset since credentials were explicitly "
-                    "defined in the dataset config."
+                    KEY_PROPAGATION_WARNING,
+                    {"keys": CREDENTIALS_KEY, "target": "underlying dataset"},
                 )
             else:
                 self._dataset_config[CREDENTIALS_KEY] = dataset_credentials
 
+        self._fs_args = deepcopy(fs_args) or {}
+        if self._fs_args:
+            if "fs_args" in self._dataset_config:
+                self._logger.warning(
+                    KEY_PROPAGATION_WARNING,
+                    {"keys": "filesystem arguments", "target": "underlying dataset"},
+                )
+            else:
+                self._dataset_config["fs_args"] = deepcopy(self._fs_args)
+
         self._filepath_arg = filepath_arg
         if self._filepath_arg in self._dataset_config:
             warn(
@@ -189,7 +206,7 @@ class PartitionedDataSet(AbstractDataSet):
         import fsspec  # pylint: disable=import-outside-toplevel
 
         protocol = "s3" if self._protocol in S3_PROTOCOLS else self._protocol
-        return fsspec.filesystem(protocol, **self._credentials)
+        return fsspec.filesystem(protocol, **self._credentials, **self._fs_args)
 
     @property
     def _normalized_path(self) -> str:
@@ -341,6 +358,7 @@ class IncrementalDataSet(PartitionedDataSet):
         filename_suffix: str = "",
         credentials: Dict[str, Any] = None,
         load_args: Dict[str, Any] = None,
+        fs_args: Dict[str, Any] = None,
     ):
 
         """Creates a new instance of ``IncrementalDataSet``.
@@ -385,13 +403,21 @@ class IncrementalDataSet(PartitionedDataSet):
                 https://kedro.readthedocs.io/en/stable/04_user_guide/08_advanced_io.html#partitioned-dataset-credentials
             load_args: Keyword arguments to be passed into ``find()`` method of
                 the filesystem implementation.
+            fs_args: Extra arguments to pass into underlying filesystem class constructor
+                (e.g. `{"project": "my-project"}` for ``GCSFileSystem``).
 
         Raises:
             DataSetError: If versioning is enabled for the underlying dataset.
         """
 
         super().__init__(
-            path, dataset, filepath_arg, filename_suffix, credentials, load_args
+            path=path,
+            dataset=dataset,
+            filepath_arg=filepath_arg,
+            filename_suffix=filename_suffix,
+            credentials=credentials,
+            load_args=load_args,
+            fs_args=fs_args,
         )
 
         self._checkpoint_config = self._parse_checkpoint_config(checkpoint)
@@ -430,8 +456,8 @@ class IncrementalDataSet(PartitionedDataSet):
 
         if CREDENTIALS_KEY in default_config.keys() & checkpoint_config.keys():
             self._logger.warning(
-                "Top-level credentials will not propagate into the checkpoint since "
-                "credentials were explicitly defined in the checkpoint config."
+                KEY_PROPAGATION_WARNING,
+                {"keys": CREDENTIALS_KEY, "target": "checkpoint"},
             )
 
         return {**default_config, **checkpoint_config}
