@@ -197,20 +197,14 @@ class Node:  # pylint: disable=too-many-instance-attributes
         return self.run(inputs=kwargs)
 
     @property
-    def _func_name(self):
-        if hasattr(self._func, "__name__"):
-            return self._func.__name__
-
-        name = repr(self._func)
-        if "functools.partial" in name:
+    def _func_name(self) -> str:
+        name = _get_readable_func_name(self._func)
+        if name == "<partial>":
             warn(
-                "The node producing outputs `{}` is made from a `partial` function. "
-                "Partial functions do not have a `__name__` attribute: consider using "
-                "`functools.update_wrapper` for better log messages.".format(
-                    self.outputs
-                )
+                f"The node producing outputs `{self.outputs}` is made from a `partial` function. "
+                f"Partial functions do not have a `__name__` attribute: consider using "
+                f"`functools.update_wrapper` for better log messages."
             )
-            name = "<partial>"
         return name
 
     @property
@@ -550,10 +544,11 @@ class Node:  # pylint: disable=too-many-instance-attributes
                 func_args = inspect.signature(
                     func, follow_wrapped=False
                 ).parameters.keys()
+                func_name = _get_readable_func_name(func)
+
                 raise TypeError(
-                    "Inputs of function expected {}, but got {}".format(
-                        str(list(func_args)), str(inputs)
-                    )
+                    f"Inputs of '{func_name}' function expected {list(func_args)}, "
+                    f"but got {inputs}"
                 ) from exc
 
     def _validate_unique_outputs(self):
@@ -677,7 +672,7 @@ def _dict_inputs_to_list(func: Callable[[Any], Any], inputs: Dict[str, str]):
     """Convert a dict representation of the node inputs to a list , ensuring
     the appropriate order for binding them to the node's function.
     """
-    sig = inspect.signature(func).bind(**inputs)
+    sig = inspect.signature(func, follow_wrapped=False).bind(**inputs)
     # for deterministic behavior in python 3.5, sort kwargs inputs alphabetically
     return list(sig.args) + sorted(sig.kwargs.values())
 
@@ -696,3 +691,20 @@ def _to_list(element: Union[None, str, Iterable[str], Dict[str, str]]) -> List:
     if isinstance(element, dict):
         return sorted(element.values())
     return list(element)
+
+
+def _get_readable_func_name(func: Callable) -> str:
+    """Get a user-friendly readable name of the function provided.
+
+    Returns:
+        str: readable name of the provided callable func.
+    """
+
+    if hasattr(func, "__name__"):
+        return func.__name__
+
+    name = repr(func)
+    if "functools.partial" in name:
+        name = "<partial>"
+
+    return name
