@@ -704,7 +704,7 @@ class Pipeline:  # pylint: disable=too-many-public-methods
 
         Args:
             decorators: Decorators to be applied on all node functions in
-            the pipeline. Decorators will be applied from right to left.
+                the pipeline, always applied from right to left.
 
         Returns:
             A new ``Pipeline`` object with all nodes decorated with the
@@ -850,9 +850,9 @@ def _topologically_sorted(node_dependencies) -> List[Set[Node]]:
 
     try:
         return list(toposort(node_dependencies))
-    except ToposortCircleError as error:
-        message = _circle_error_message(error.data)
-        raise CircularDependencyError(message) from error
+    except ToposortCircleError as exc:
+        message = _circle_error_message(exc.data)
+        raise CircularDependencyError(message) from exc
 
 
 class CircularDependencyError(Exception):
